@@ -5,6 +5,10 @@ from django.contrib.messages import constants
 def message_user(user, message, level=constants.INFO):
     """
     Send a message to a particular user.
+
+    :param user: User instance
+    :param message: Message to show
+    :param level: Message level
     """
     cache.set(_user_key(user), (message, level))
 
@@ -12,6 +16,10 @@ def message_user(user, message, level=constants.INFO):
 def message_users(users, message, level=constants.INFO):
     """
     Send a message to a group of users.
+
+    :param users: Users queryset 
+    :param message: Message to show
+    :param level: Message level
     """
     for user in users:
         message_user(user, message, level)
@@ -20,6 +28,8 @@ def message_users(users, message, level=constants.INFO):
 def get_message(user):
     """
     Fetch a message for given user.  Returns None if no such message exists.
+
+    :param user: User instance
     """
     key = _user_key(user)
     result = cache.get(key)
